@@ -10,33 +10,33 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.9-78.14AXS2.src.rpm ]
+if [ ! -r kernel-2.6.9-89.11.AXS2.src.rpm ]
 then
-    wget http://ftp.miraclelinux.com/pub/Miracle/ia32/standard/4.0/updates/SRPMS/kernel-2.6.9-78.14AXS2.src.rpm || die "Can't download source package."
+    wget http://ftp.miraclelinux.com/pub/Miracle/ia32/standard/4.0/updates/SRPMS/kernel-2.6.9-89.11.AXS2.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.9-78.14AXS2.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.9-89.11.AXS2.src.rpm || die "Can't install source package."
 
 cd /usr/src/asianux/SOURCES/ || die "Can't chdir to /usr/src/asianux/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20090911.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20100604.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090911.tar.gz || die "Can't download patch."
+    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.8-20100604.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/asianux/SPECS/kernel-2.6.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6.spec	2009-07-16 15:22:03.000000000 +0900
-+++ kernel-2.6.spec	2009-08-09 19:36:35.000000000 +0900
-@@ -34,7 +34,7 @@
+--- kernel-2.6.spec
++++ kernel-2.6.spec
+@@ -26,7 +26,7 @@
+ # that the kernel isn't the stock distribution kernel, for example by
+ # adding some text to the end of the version number.
  #
- %define axbsys %([ "%{?WITH_LKST}" -eq 0 ] && echo || echo .lkst)
- %define dist AXS2
--%define release 78.14%{?dist}%{axbsys}
-+%define release 78.14%{?dist}%{axbsys}_tomoyo_1.6.8p1
+-%define release 89.11%{?dist}
++%define release 89.11%{?dist}_tomoyo_1.6.8p3
  %define sublevel 9
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
-@@ -147,6 +147,9 @@
+@@ -139,6 +139,9 @@
  # to versions below the minimum
  #
  
@@ -46,7 +46,7 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -183,7 +186,7 @@
+@@ -175,7 +178,7 @@
  %define __find_provides /usr/lib/rpm/asianux/find-kmod-provides.sh
  %define __find_requires %{nil}
  
@@ -55,18 +55,18 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -5241,6 +5244,10 @@
+@@ -6198,6 +6201,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20090911.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20100604.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.9-asianux-2.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -5252,6 +5259,9 @@
+@@ -6209,6 +6216,9 @@
  for i in *.config 
  do 
  	mv $i .config 
