@@ -10,29 +10,29 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.30.9-96.fc11.src.rpm ]
+if [ ! -r kernel-2.6.30.10-105.2.23.fc11.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/11/SRPMS/kernel-2.6.30.9-96.fc11.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/11/SRPMS/kernel-2.6.30.10-105.2.23.fc11.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.30.9-96.fc11.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.30.10-105.2.23.fc11.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20091111.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20100604.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20091111.tar.gz || die "Can't download patch."
+    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.8-20100604.tar.gz || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
 cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- ccs-kernel.spec	2009-11-04 13:23:12.000000000 +0900
-+++ ccs-kernel.spec	2009-11-07 08:46:39.895977403 +0900
+--- ccs-kernel.spec
++++ ccs-kernel.spec
 @@ -15,7 +15,7 @@
  # that the kernel isn't the stock distribution kernel, for example,
  # by setting the define to ".local" or ".bz123456"
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.6.8p1
++%define buildid _tomoyo_1.6.8p3
  
  # fedora_build defines which build revision of this kernel version we're
  # building. Rather than incrementing forever, as with the prior versioning
@@ -66,7 +66,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -928,7 +933,7 @@
+@@ -993,7 +998,7 @@
  Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
@@ -75,18 +75,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1565,6 +1570,10 @@
+@@ -1692,6 +1697,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20091111.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20100604.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.30-fedora-11.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1591,6 +1600,9 @@
+@@ -1718,6 +1727,9 @@
  for i in *.config
  do
    mv $i .config
