@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 10.3's 2.6.22 kernel.
+# This is a kernel build script for openSUSE 11.0's 2.6.25 kernel.
 #
 
 die () {
@@ -13,9 +13,9 @@ cd /usr/lib/rpm/ || die "Can't chdir to /usr/lib/rpm/ ."
 if ! grep -q ccs-kernel find-supplements.ksyms
 then
 	patch << "EOF" || die "Can't patch find-supplements.ksyms ."
---- find-supplements.ksyms	2008-04-16 14:18:13.000000000 +0900
-+++ find-supplements.ksyms	2008-04-16 14:19:06.000000000 +0900
-@@ -6,6 +6,7 @@
+--- find-supplements.ksyms
++++ find-supplements.ksyms
+@@ -7,6 +7,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
  		       # kernel-module.
@@ -29,8 +29,8 @@ fi
 if ! grep -q ccs-kernel find-requires.ksyms
 then
 	patch << "EOF" || die "Can't patch find-requires.ksyms ."
---- find-requires.ksyms	2008-04-16 14:20:34.000000000 +0900
-+++ find-requires.ksyms	2008-04-16 14:21:06.000000000 +0900
+--- find-requires.ksyms
++++ find-requires.ksyms
 @@ -5,6 +5,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
@@ -45,8 +45,8 @@ fi
 if ! grep -q ccs-kernel find-provides.ksyms
 then
 	patch << "EOF" || die "Can't patch find-provides.ksyms ."
---- find-provides.ksyms	2008-04-16 14:22:34.000000000 +0900
-+++ find-provides.ksyms	2008-04-16 14:23:04.000000000 +0900
+--- find-provides.ksyms
++++ find-provides.ksyms
 @@ -5,6 +5,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
@@ -60,38 +60,38 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.22.19-0.4.src.rpm ]
+if [ ! -r kernel-source-2.6.25.20-0.7.src.rpm ]
 then
-    wget http://download.opensuse.org/update/10.3/rpm/src/kernel-source-2.6.22.19-0.4.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.0/rpm/src/kernel-source-2.6.25.20-0.7.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-source-2.6.22.19-0.4.src.rpm || die "Can't install source package."
+rpm -ivh kernel-source-2.6.25.20-0.7.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20100120.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20100604.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20100120.tar.gz || die "Can't download patch."
+    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.8-20100604.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/packages/SOURCES/kernel-default.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-default.spec	2009-05-28 19:02:43.000000000 +0900
-+++ kernel-default.spec	2009-06-09 09:45:35.000000000 +0900
-@@ -44,10 +44,10 @@
- %define build_vanilla 1
+--- kernel-default.spec
++++ kernel-default.spec
+@@ -49,10 +49,10 @@
+ %define build_nomodules 1
  %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel for both Uniprocessor and Multiprocessor Systems
- Version:        2.6.22.19
--Release: 0.4
-+Release: 0.4_tomoyo_1.6.8p3
+ Version:        2.6.25.20
+-Release: 0.7
++Release: 0.7_tomoyo_1.6.8p3
  License:        GPL v2 or later
  Group:          System/Kernel
- AutoReqProv:    on
-@@ -198,7 +198,7 @@
- %define tolerate_unknown_new_config_options 0
+ Url:            http://www.kernel.org/
+@@ -227,7 +227,7 @@
+ 
  # kABI change tolerance (default in maintenance should be 4, 6, 8 or 15,
  # 31 is the maximum; see scripts/kabi-checks)
 -%define tolerate_kabi_changes 6
@@ -99,13 +99,13 @@ patch << "EOF" || die "Can't patch spec file."
  
  %description
  The standard kernel for both uniprocessor and multiprocessor systems.
-@@ -289,6 +289,10 @@
- %build
+@@ -343,6 +343,10 @@
  source .rpm-defs
- cd linux-2.6.22
+ 
+ cd linux-2.6.25
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.6.8-20100120.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.22-suse-10.3.diff
++tar -zxf %_sourcedir/ccs-patch-1.6.8-20100604.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.25-suse-11.0.diff
 +cat config.ccs >> .config
  cp .config .config.orig
  %if %{tolerate_unknown_new_config_options}
