@@ -20,9 +20,9 @@ done
 # Download TOMOYO Linux patches.
 mkdir -p /usr/src/rpm/SOURCES/
 cd /usr/src/rpm/SOURCES/ || die "Can't chdir to /usr/src/rpm/SOURCES/ ."
-if [ ! -r ccs-patch-1.6.8-20090911.tar.gz ]
+if [ ! -r ccs-patch-1.6.8-20100604.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/30297/ccs-patch-1.6.8-20090911.tar.gz || die "Can't download patch."
+    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/30297/ccs-patch-1.6.8-20100604.tar.gz || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -36,20 +36,47 @@ apt-get source linux-restricted-modules-${VERSION}-generic || die "Can't install
 
 # Apply patches and create kernel config.
 cd linux-2.6.27/ || die "Can't chdir to linux-2.6.27/ ."
-tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.6.8-20090911.tar.gz || die "Can't extract patch."
+tar -zxf /usr/src/rpm/SOURCES/ccs-patch-1.6.8-20100604.tar.gz || die "Can't extract patch."
 patch -p1 < patches/ccs-patch-2.6.27-ubuntu-8.10.diff || die "Can't apply patch."
-for i in `find debian/ -type f -name '*generic*'`; do cp -p $i `echo $i | sed -e 's/generic/ccs/g'`; done
-for i in debian/config/*/config; do cat config.ccs >> $i; done
-touch debian/control.stub.in || die "Can't touch control."
+rm -fR patches/ specs/ || die "Can't delete patch."
+for i in `find debian.master/ -type f -name '*generic*'`; do cp -p $i `echo $i | sed -e 's/generic/ccs/g'`; done
+for i in debian.master/config/*/config; do cat config.ccs >> $i; done
+rm debian.master/control.stub || die "Can't delete control.stub."
+make -f debian.master/rules debian.master/control.stub || die "Can't update control.stub."
+rm debian/control || die "Can't delete control."
 debian/rules debian/control || die "Can't update control."
-for i in debian/abi/2.6.27-*/*/ ; do touch $i/ccs.ignore; done
+for i in debian.master/abi/2.6.27-*/*/ ; do touch $i/ccs.ignore; done
+
+# Make modified header files go into local header package.
+patch -p0 << "EOF" || die "Can't patch link-headers."
+--- debian.master/scripts/link-headers
++++ debian.master/scripts/link-headers
+@@ -37,4 +37,17 @@
+ done
+ )
+ 
++if [ $flavour == "ccs" ]
++then
++    cd $hdrdir/../../../../$symdir/usr/src/$symdir/include/linux/
++    for i in sched.h init_task.h ccs_common.h ccs_compat.h ccs_proc.h realpath.h sakura.h syaoran.h tomoyo.h tomoyo_socket.h tomoyo_vfs.h
++    do
++	rm -f $hdrdir/include/linux/$i
++	cp -p $i $hdrdir/include/linux/
++    done
++    rm -f $hdrdir/fs
++    cd ../../
++    tar -cf - fs | ( cd $hdrdir ; tar -xf - )
++fi
++
+ exit
+EOF
 
 # Start compilation.
 debian/rules binary-headers || die "Failed to build kernel package."
 debian/rules binary-debs flavours=ccs || die "Failed to build kernel package."
 
 # Install header package for compiling additional modules.
-dpkg -i /usr/src/linux-headers-${VERSION}*.deb || die "Can't install packages."
+dpkg -i /usr/src/linux-headers-*-ccs*.deb || die "Can't install packages."
 cd /usr/src/linux-restricted-modules-2.6.27/ || die "Can't chdir to /usr/src/linux-restricted-modules-2.6.27/ ."
 for i in `find debian/ -type f -name '*generic*'`; do cp -p $i `echo $i | sed -e 's/generic/ccs/g'`; done
 touch debian/control.stub.in || die "Can't touch control."
